@@ -1,5 +1,3 @@
-import sys
-
 class Logger:
     def __init__(self, level):
         self.level = level
@@ -18,5 +16,12 @@ class Logger:
     def flush(self):
         pass
 
+    def getvalue(self):
+        """
+        This function only serves to prevent PyCharm unit tests from failing when the stdout is redirected to the
+        Logger.
+        """
+        pass
+
 
 # vim:sw=4:ts=4:et:
